@@ -10,14 +10,14 @@ This script shows you example how you can use C<get_logger()>.
 
 =head1 POWERED BY
 
-     _    __ _____ _____ __  __ __ __   __
-    | |__|  |     |     |  \|  |__|\  \/  /
-    |  . |  |  |  |  |  |      |  | >    <
-    |____|__|_____|_____|__|\__|__|/__/\__\
+     _    __ ____ ____ __  __ __ __   __
+    | |__|  |    |    |  \|  |__|\  \/  /
+    |  . |  |  | |  | |      |  | >    <
+    |____|__|____|____|__|\__|__|/__/\__\
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -26,17 +26,15 @@ modify it under the same terms as Perl itself.
 
 use strict;
 use warnings;
-use Log::Handler MyApp => "LOG";
+use Log::Handler 'myapp' => 'LOG';
 use lib '.';
 use MyApp;
 
-LOG->add(
-    screen => {
-        newline  => 1,
-        maxlevel => 'info',
-        message_layout => '%L - %m',
-    }
-);
+LOG->add(screen => {
+    newline  => 1,
+    maxlevel => 'info',
+    message_layout => '%L - %m',
+});
 
 LOG->info('message from main');
 
